@@ -23,6 +23,7 @@
 #define AUDIOBASE_H
 
 #include <string>
+#include <cstring>
 
 #include "IAudio.h"
 #include "AudioConfig.h"
@@ -43,7 +44,7 @@ protected:
     };
 
 private:
-    const char *_backendName;
+    const char *m_backendName;
     std::string _errorString;
 
 protected:
@@ -53,7 +54,7 @@ protected:
 protected:
     void setError(const char* msg)
     {
-        _errorString.assign(_backendName).append(" ERROR: ").append(msg);
+        _errorString.assign(m_backendName).append(" ERROR: ").append(msg);
     }
 
     void clearError()
@@ -63,12 +64,14 @@ protected:
 
 public:
     AudioBase(const char* name) :
-        _backendName(name),
+        m_backendName(name),
         _sampleBuffer(nullptr) {}
     ~AudioBase() override = default;
 
     short *buffer() const override { return _sampleBuffer; }
 
+    void clearBuffer() override { std::memset(_sampleBuffer, 0, _settings.getBufBytes()); }
+
     void getConfig(AudioConfig &cfg) const override
     {
         cfg = _settings;
@@ -78,6 +81,11 @@ public:
     {
         return _errorString.c_str();
     }
+
+    const char *getDriverString() const override
+    {
+        return m_backendName;
+    }
 };
 
 #endif // AUDIOBASE_H
