@@ -37,8 +37,8 @@
 int _getch (void);
 #endif
 
-#define MAX_CMDLEN 10
-#define ESC '\033'
+constexpr int MAX_CMDLEN = 10;
+constexpr char ESC = '\033';
 
 // Special Extended Key Definitions
 enum
@@ -244,7 +244,11 @@ int _getch (void)
 {
     char ch = -1;
     if (infd >= 0)
-        read (infd, &ch, 1);
+    {
+        ssize_t res = read (infd, &ch, 1);
+        if (res < 0)
+            return -1;
+    }
     return ch;
 }
 
