@@ -294,9 +294,7 @@ void ConsolePlayer::menu ()
         const uint_least32_t seconds = m_timer.stop / 1000;
         cerr << setw(2) << setfill('0') << ((seconds / 60) % 100)
              << ':' << setw(2) << setfill('0') << (seconds % 60);
-#ifdef FEAT_NEW_SONLEGTH_DB
         cerr << '.' << setw(3) << m_timer.stop % 1000;
-#endif
     }
     else if (m_timer.valid)
         cerr << "FOREVER";
@@ -353,31 +351,17 @@ void ConsolePlayer::menu ()
         cerr << " SID Details  : ";
         consoleColour (color_t::white, false);
         cerr << "Model = ";
-#ifdef FEAT_NEW_TUNEINFO_API
         cerr << getModel(tuneInfo->sidModel(0));
-#else
-        cerr << getModel(tuneInfo->sidModel1());
-#endif
         cerr << endl;
-#ifdef FEAT_NEW_TUNEINFO_API
         if (tuneInfo->sidChips() > 1)
-#else
-        if (tuneInfo->isStereo())
-#endif
         {
             consoleTable  (table_t::middle);
             consoleColour (color_t::yellow, true);
             cerr << "              : ";
             consoleColour (color_t::white, false);
-#ifdef FEAT_NEW_TUNEINFO_API
             cerr << "2nd SID = $" << hex << tuneInfo->sidChipBase(1) << dec;
             cerr << ", Model = " << getModel(tuneInfo->sidModel(1));
-#else
-            cerr << "2nd SID = $" << hex << tuneInfo->sidChipBase2() << dec;
-            cerr << ", Model = " << getModel(tuneInfo->sidModel2());
-#endif
             cerr << endl;
-#ifdef FEAT_NEW_TUNEINFO_API
             if (tuneInfo->sidChips() > 2)
             {
                 consoleTable  (table_t::middle);
@@ -388,7 +372,6 @@ void ConsolePlayer::menu ()
                 cerr << ", Model = " << getModel(tuneInfo->sidModel(2));
                 cerr << endl;
             }
-#endif
         }
 
         consoleTable  (table_t::separator);
@@ -410,13 +393,13 @@ void ConsolePlayer::menu ()
         cerr << " SID Filter   : ";
         consoleColour (color_t::white, false);
         cerr << (m_filter.enabled ? "Yes" : "No") << endl;
-#ifdef FEAT_DIGIBOOST
+
         consoleTable  (table_t::middle);
         consoleColour (color_t::yellow, true);
         cerr << " DigiBoost    : ";
         consoleColour (color_t::white, false);
         cerr << (m_engCfg.digiBoost ? "Yes" : "No") << endl;
-#endif
+
         consoleTable  (table_t::middle);
         consoleColour (color_t::yellow, true);
         cerr << " SID Model    : ";
@@ -496,7 +479,11 @@ void ConsolePlayer::menu ()
         consoleTable  (table_t::separator);
         consoleTable (table_t::middle); cerr << "         NOTE PW         CONTROL          WAVEFORMS" << endl;
 
+#ifdef FEAT_NEW_PLAY_API
+        for (unsigned int i=0; i < m_engine.installedSIDs() * 3; i++)
+#else
         for (int i=0; i < tuneInfo->sidChips() * 3; i++)
+#endif
         {
             consoleTable (table_t::middle); cerr << endl; // reserve space for the Voice 3 status
         }
@@ -522,11 +509,15 @@ void ConsolePlayer::refreshRegDump()
 #ifdef FEAT_REGS_DUMP_SID
     if (m_verboseLevel > 1)
     {
-        const SidTuneInfo *tuneInfo = m_tune.getInfo();
+        unsigned int chips =
+#ifdef FEAT_NEW_PLAY_API
+            m_engine.installedSIDs();
+#else
+            m_tune.getInfo()->sidChips();
+#endif
+        cerr << "\x1b[" << chips * 3 + 1 << "A\r"; // Moves cursor X lines up
 
-        cerr << "\x1b[" << tuneInfo->sidChips() * 3 + 1 << "A\r"; // Moves cursor X lines up
-
-        for (int j=0; j < tuneInfo->sidChips(); j++)
+        for (unsigned int j=0; j < chips; j++)
         {
             uint8_t* registers = m_registers[j];
             uint8_t oldCtl[3];
@@ -685,7 +676,7 @@ void ConsolePlayer::consoleTable (table_t table)
 void ConsolePlayer::consoleRestore ()
 {
     if ((m_iniCfg.console ()).ansi) {
-    cerr << '\x1b' << "[?25h";
+        cerr << '\x1b' << "[?25h";
         cerr << '\x1b' << "[0m";
     }
 }
